package com.caimei365.user.mapper;

import com.caimei365.user.model.dto.ShopUpdateDto;
import com.caimei365.user.model.po.ArticlePo;
import com.caimei365.user.model.po.ShopCertPo;
import com.caimei365.user.model.po.UserPo;
import com.caimei365.user.model.vo.*;
import org.apache.ibatis.annotations.MapKey;
import org.apache.ibatis.annotations.Mapper;

import java.util.List;
import java.util.Map;

/**
 * Description
 *
 * @author : Aslee
 * @date : 2021/3/16
 */
@Mapper
public interface ShopMapper {
    /**
     * 根据Id查询供应商
     * @param shopId    供应商Id
     * @return ShopVo
     */
    ShopVo getShopById(Integer shopId);

    /**
     * 修改供应商信息保存用户
     * @param user  用户数据
     */
    void updateShopUserByUpdateInfo(UserPo user);

    /**
     * 修改供应商信息保存供应商
     * @param shop  供应商数据
     */
    void updateShopByUpdateInfo(ShopUpdateDto shop);

    /**
     * 根据供应商Id和资质证书类型Id获取供应商资质证书
     * @param shopId            供应商Id
     * @param shopCertTypeId    资质证书类型Id
     * @return String
     */
    List<String> getShopCert(Integer shopId, Integer shopCertTypeId);

    /**
     * 根据供应商Id删除供应商资质证书数据
     * @param shopId    供应商Id
     */
    void deleteShopCertByShopId(Integer shopId);

    /**
     * 保存供应商资质证书
     * @param shopCert  资质证书数据
     */
    void insertShopCert(ShopCertPo shopCert);

    /**
     * 供应商首页数据
     * @param shopId 供应商Id
     */
    ShopHomeVo getShopHomeData(Integer shopId);

    /**
     * 公司资质照片
     */
    List<String> getShopCertById(Integer shopId, int shopCertTypeId);
    /**
     * 医疗器械经营许可
     */
    String medicalPracticeLicense(Integer shopId);

    /**
     * 供应商首页-轮播图片
     */
    List<ShopBannerVo> getShopHomeImages(Integer shopId);
    /**
     * 店铺促销活动
     */
    PromotionsVo getShopPromotionsByShopId(Integer shopId);
    /**
     * 促销赠品
     */
    List<ProductItemVo> getPromotionsGifts(Integer promotionsId);
    /**
     * 统计商品数量
     *
     * @param shopId    供应商id
     * @param validFlag 商品状态
     */
    Integer getShopProductCount(Integer shopId, Integer validFlag);
    /**
     * 统计前五的商品销售信息
     */
    @MapKey("productId")
    List<Map<String, Object>> getSalesRankingList(Integer shopId);
    /**
     * 获取商品信息
     */
    ProductItemVo getProductShown(Integer productId);
    /**
     * 销售统计
     */
    @MapKey("orderQuantity")
    Map<String, Object> getSalesStatistics(Integer shopId, String startTime, String endTime);
    /**
     * 轮播图片数量
     */
    int getShopHomeImageCount(Integer shopId);
    /**
     * 新增轮播图
     */
    void insertShopHomeImage(ShopBannerVo shopBanner);
    /**
     * 更新轮播图
     */
    void updateShopHomeImage(ShopBannerVo shopBanner);
    /**
     * 删除轮播图
     */
    void deleteShopHomeImage(Integer id);
}
