package com.caimei365.user.service;

import com.caimei365.user.model.ResponseJson;
import com.caimei365.user.model.dto.ClubRemarksDto;
import com.caimei365.user.model.dto.ClubUpdateDto;
import com.caimei365.user.model.dto.JsonParamsDto;
import com.caimei365.user.model.vo.*;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;
import java.util.Map;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/3/15
 */
public interface ClubService {
    /**
     * 根据用户Id查询机构资料
     *
     * @param userId 用户Id
     * @return Map(userPo, clubPo)
     */
    ResponseJson<Map<String, Object>> getClubUserInfo(Integer userId);

    ResponseJson<Map<String, Object>> recordLinkage(Integer clubId);

    /**
     * 修改机构资料
     *
     * @param club ClubUpgradeDto:{
     *             clubId                 机构ID
     *             userId                 用户ID
     *             name                   机构名称
     *             shortName                  机构简称(shortName)
     *             contractEmail          邮箱（contractEmail1）
     *             contractPhone          固定电话
     *             linkMan                联系人（linkMan1）
     *             provinceId             省Id
     *             cityId                 市Id
     *             townId                 县区Id
     *             address                地址
     *             shopPhoto              门头照(headpic)
     *             businessLicense        营业执照（businessLicenseImage）
     *             socialCreditCode       统一社会信用代码（socialCreditCode）
     *             firstClubType          一级分类：医美=1和生美=2
     *             secondClubType         医美的二级分类：诊所=1、门诊=2、医院=3。  生美没有二级分类
     *             department             医美分类下的门诊和医院则需要填写科室
     *             medicalPracticeLicense 医美分类必须上传医疗执业许可证（medicalPracticeLicenseImg）
     *             mainProduct            主打项目（mainpro）
     *             fax                    传真
     *             profile                公司简介
     *             }
     * @return ClubUpdateDto
     */
    ResponseJson<ClubUpdateDto> updateClubUserInfo(ClubUpdateDto club);

    /**
     * 机构个人中心
     *
     * @param userId 用户Id
     * @return Map(userPo, clubPo)
     */
    ResponseJson<Map<String, Object>> getClubHomeData(Integer userId);

    /**
     * 赠送采美豆弹窗
     *
     * @param userId 用户Id
     * @return
     */
    ResponseJson<BeansHistoryVo> beansPopUps(Integer userId);

    /**
     * 采美豆收支明细
     *
     * @param userId   用户Id
     * @param year     年份
     * @param month    月份
     * @param type     收支类型：1收入，2支出
     * @param pageNum  第几页
     * @param pageSize 一页多少条
     * @return
     */
    ResponseJson<Map<String, Object>> beansHistory(Integer userId, Integer year, Integer month, Integer type, int pageNum, int pageSize);

    /**
     * 查看商品资料抵扣采美豆
     *
     * @param userId    用户Id
     * @param archiveId 商品资料id
     * @return
     */
    ResponseJson archiveDeduction(Integer userId, Integer archiveId);

    /**
     * 保存机构资料备注
     *
     * @param jsonParamsDto:{ remarksId:           备注id,
     *                        机构id:               机构id,
     *                        questionMan:        咨询人姓名，
     *                        serviceProviderId:   协销id,
     *                        remarks:             文字备注,
     *                        fileList:    [{fileName:"文件名称",ossName:"oss文件名称"},{fileName:"文件名称",ossName:"oss文件名称"}...]
     *                        imageList:   ["图片","图片",...]
     *                        consult: (1,2) 咨询类别id，英文逗号隔开
     *                        }
     * @return
     * @return
     */
    ResponseJson saveClubRemarks(JsonParamsDto jsonParamsDto);

    ResponseJson saveClubReport(ReportVo reportVo);

    ResponseJson<PaginationVo<ProductItemVo>> getproductList(String keyWord, int pageNum, int pageSize);

    ResponseJson<PaginationVo<ReportVo>> ClubReportList(Integer serviceProviderId, Integer clubId, String keyWord, int pageNum, int pageSize);

    ResponseJson<PaginationVo<ReportVo>> visitorReportList(String questionManId, String keyWord, int pageNum, int pageSize);

    ResponseJson addVisitorReport(ReportVo reportVo);

    ResponseJson<ReportVo> reportDetailsList(Integer reportId);

    ResponseJson<ReportVo> visitorReportsList(Integer reportId);

    ResponseJson<PaginationVo<RemarkVo>> associated(Integer manager, Integer serviceProviderId, Integer reportId, String keyWord, String startAddTime,
                                                    String endAddTime,
                                                    String consult,
                                                    Integer leaderId,
                                                    String clubType,
                                                    Integer pinceSensitve,
                                                    Integer satisfied,
                                                    Integer followup,
                                                    String extra,
                                                    Integer groupId, Integer newDeal, Integer status, int pageNum, int pageSize);

    ResponseJson<PaginationVo<RemarkVo>> visitorAssociated(Integer manager, Integer serviceProviderId, Integer reportId, String keyWord, String startAddTime,
                                                           String endAddTime,
                                                           String consult,
                                                           Integer leaderId,
                                                           String clubType,
                                                           Integer pinceSensitve,
                                                           Integer satisfied,
                                                           Integer followup,
                                                           String extra,
                                                           Integer groupId, Integer status, int pageNum, int pageSize);

    ResponseJson disassociation(Integer remarksId);

    ResponseJson visitorDisassociation(Integer remarksId);


    /**
     * 获取机构资料备注列表
     *
     * @param serviceProviderId 协销id
     * @param pageNum           页码
     * @param pageSize          每页数量
     * @return
     */
    ResponseJson<PaginationVo<RemarkVo>> getRemarksList(Integer serviceProviderId,
                                                        String keyWord,
                                                        String startAddTime,
                                                        String endAddTime,
                                                        String consult,
                                                        Integer leaderId,
                                                        Integer manager,
                                                        String clubType,
                                                        Integer pinceSensitve,
                                                        Integer satisfied,
                                                        Integer followup,
                                                        String extra,
                                                        Integer groupId, Integer status, Integer newDeal, int pageNum, int pageSize);

    /**
     * 获取机构资料备注详情
     *
     * @param remarksId 备注id
     * @return
     */
    ResponseJson<RemarkVo> getRemarksDetail(Integer remarksId);

    /**
     * 删除机构资料备注
     *
     * @param remarksId 备注id
     * @return
     */
    ResponseJson deleteClubRemarks(Integer remarksId);

    /**
     * 机构个人中心数据
     *
     * @param userId 用户Id
     */
    ResponseJson<Map<String, Object>> getPersonalData(Integer userId);

    /**
     * 添加潜在用户姓名
     *
     * @param name
     * @return
     */
    ResponseJson<Map<String, String>> saveVisitorName(String name, String serviceProviderId);

    /**
     * 获取潜在客户列表
     *
     * @param serviceProviderId
     * @return
     */
    ResponseJson<PaginationVo<VisitorRemarkVo>> getVisitorList(Integer serviceProviderId,
//                                                               String startAddTime,
//                                                               String endAddTime,
//                                                               String consult,
//                                                               Integer leaderId,
//                                                               Integer manager,
//                                                               Integer groupId,
                                                               int pageNum, int pageSize);

    /**
     * 修改潜在客户咨询人姓名
     *
     * @param serviceProviderId
     * @param questionMan
     * @param questionManId
     * @return
     */
    ResponseJson<String> updateVisitor(String serviceProviderId, String questionMan, String questionManId);

    /**
     * 新增/修改记录
     *
     * @param visitor
     * @return
     */
    ResponseJson saveVisitRecord(JsonParamsDto visitor);

    /**
     * 潜在用户资料详情
     *
     * @param remarksId
     * @return
     */
    ResponseJson<VisitRemarkVo> getVisitRemark(Integer remarksId);

    ResponseJson<PaginationVo<VisitRemarkVo>> getVisitorRecordList(String questionManId, String keyWord, Integer serviceProviderId, String startAddTime, String endAddTime, String consult, Integer leaderId, Integer groupId, Integer manager, String clubType, Integer pinceSensitve, Integer satisfied, Integer followup, String extra, Integer status, int pageNum, int pageSize);

    ResponseJson deleteVisitRemarks(String remarksId);

    /**
     * 同步潜在用户信息到机构
     *
     * @param clubId
     * @param questionManId
     * @return
     */
    ResponseJson concactVisitRemarks(String clubId, String questionManId);

    ResponseJson findConsults(String consults);

    ResponseJson findTeams();

    ResponseJson findGroups(Integer leaderId);

    ResponseJson getCmRemarksList(String remarks);

    ResponseJson<PaginationVo<ReportVo>> reportRemarks(Integer manager, Integer serviceProviderId, String keyWord, int pageNum, int pageSize);

    ResponseJson<PaginationVo<ReportVo>> visitorReportRemarks(Integer manager, Integer serviceProviderId, String keyWord, int pageNum, int pageSize);

    ResponseJson deleteReport(Integer reportId);

    ResponseJson<List<ServiceProviderVo>> choseSales(Integer spId);

    ResponseJson changeSales(Integer clubId, Integer spId, Integer choseServiceId);
}
